==> qt5-script-debuginfo-5.9.2-1.tar.xz: usr/src/debug/qt5-script-5.9.2-1/examples/script/helloscript/.rcc/qrc_helloscript.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-script/qt5-script-5.9.2-1.i686/src/qtscript-opensource-src-5.9.2/examples/script/helloscript/helloscript.js
  0x0,0x0,0x0,0x6d,
  0x2f,
  0x2f,0x21,0x20,0x5b,0x30,0x5d,0xa,0x62,0x75,0x74,0x74,0x6f,0x6e,0x2e,0x74,0x65,
  0x78,0x74,0x20,0x3d,0x20,0x71,0x73,0x54,0x72,0x28,0x27,0x48,0x65,0x6c,0x6c,0x6f,
  0x20,0x57,0x6f,0x72,0x6c,0x64,0x21,0x27,0x29,0x3b,0xa,0x62,0x75,0x74,0x74,0x6f,
  0x6e,0x2e,0x73,0x74,0x79,0x6c,0x65,0x53,0x68,0x65,0x65,0x74,0x20,0x3d,0x20,0x27,
  0x66,0x6f,0x6e,0x74,0x2d,0x73,0x74,0x79,0x6c,0x65,0x3a,0x20,0x69,0x74,0x61,0x6c,
  0x69,0x63,0x27,0x3b,0xa,0x62,0x75,0x74,0x74,0x6f,0x6e,0x2e,0x73,0x68,0x6f,0x77,
  0x28,0x29,0x3b,0xa,0x2f,0x2f,0x21,0x20,0x5b,0x30,0x5d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // helloscript.js
  0x0,0xe,
  0x1,0x61,0xbd,0xf3,
  0x0,0x68,
  0x0,0x65,0x0,0x6c,0x0,0x6c,0x0,0x6f,0x0,0x73,0x0,0x63,0x0,0x72,0x0,0x69,0x0,0x70,0x0,0x74,0x0,0x2e,0x0,0x6a,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/helloscript.js
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5e,0x62,0xfa,0x43,0x50,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_helloscript)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_helloscript)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_helloscript)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_helloscript)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_helloscript)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_helloscript)(); }
   } dummy;
}

==> qt5-script-debuginfo-5.9.3-1.tar.xz: usr/src/debug/qt5-script-5.9.3-1/examples/script/helloscript/.rcc/qrc_helloscript.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-script/qt5-script-5.9.3-1.i686/src/qtscript-opensource-src-5.9.3/examples/script/helloscript/helloscript.js
  0x0,0x0,0x0,0x6d,
  0x2f,
  0x2f,0x21,0x20,0x5b,0x30,0x5d,0xa,0x62,0x75,0x74,0x74,0x6f,0x6e,0x2e,0x74,0x65,
  0x78,0x74,0x20,0x3d,0x20,0x71,0x73,0x54,0x72,0x28,0x27,0x48,0x65,0x6c,0x6c,0x6f,
  0x20,0x57,0x6f,0x72,0x6c,0x64,0x21,0x27,0x29,0x3b,0xa,0x62,0x75,0x74,0x74,0x6f,
  0x6e,0x2e,0x73,0x74,0x79,0x6c,0x65,0x53,0x68,0x65,0x65,0x74,0x20,0x3d,0x20,0x27,
  0x66,0x6f,0x6e,0x74,0x2d,0x73,0x74,0x79,0x6c,0x65,0x3a,0x20,0x69,0x74,0x61,0x6c,
  0x69,0x63,0x27,0x3b,0xa,0x62,0x75,0x74,0x74,0x6f,0x6e,0x2e,0x73,0x68,0x6f,0x77,
  0x28,0x29,0x3b,0xa,0x2f,0x2f,0x21,0x20,0x5b,0x30,0x5d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // helloscript.js
  0x0,0xe,
  0x1,0x61,0xbd,0xf3,
  0x0,0x68,
  0x0,0x65,0x0,0x6c,0x0,0x6c,0x0,0x6f,0x0,0x73,0x0,0x63,0x0,0x72,0x0,0x69,0x0,0x70,0x0,0x74,0x0,0x2e,0x0,0x6a,0x0,0x73,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/helloscript.js
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x39,0xae,0x82,0xf8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_helloscript)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_helloscript)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_helloscript)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_helloscript)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_helloscript)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_helloscript)(); }
   } dummy;
}
